@@ -29,10 +29,10 @@ class AbstractAction(ABC):
   def executeVertical(self, args:dict):
     raise NotImplementedError
 
-  def open(inputData):
+  def open(self, inputData):
     return InputAdaptorHandler.withInput(inputData).getContent()
 
-  def saveAs(data, filePath:str):
+  def saveAs(self, data, filePath:str):
     return OutputAdaptorHandler.withFile(filePath).save(data)
 
   
