@@ -1,7 +1,7 @@
 import os
 import argparse
 
-from src.AbstractAction import AbstractAction
+from .AbstractAction import AbstractAction
 
 class ArgParser:
   parser = None
